@@ -26,7 +26,8 @@ if not ENV_FILE.exists():
 
     JAVA_EXECUTABLE = os.getenv("PYLAV__JAVA_EXECUTABLE", "java")
     LINKED_BOT_IDS = list(map(str.strip, os.getenv("PYLAV__LINKED_BOT_IDS", "").split("|")))
-    USE_BUNDLED_EXTERNAL_NODES = bool(int(os.getenv("PYLAV__USE_BUNDLED_EXTERNAL_NODES", "1")))
+    USE_BUNDLED_EXTERNAL_LAVA_LINK_NODE = bool(int(os.getenv("PYLAV__USE_BUNDLED_EXTERNAL_LAVA_LINK_NODE", "0")))
+    USE_BUNDLED_EXTERNAL_PYLAV_NODE = bool(int(os.getenv("PYLAV__USE_BUNDLED_EXTERNAL_PYLAV_NODE", "1")))
 
     REDIS_FULL_ADDRESS_RESPONSE_CACHE = os.getenv("PYLAV__REDIS_FULL_ADDRESS_RESPONSE_CACHE")
 
@@ -50,7 +51,8 @@ if not ENV_FILE.exists():
         "PYLAV__REDIS_FULLADDRESS_RESPONSE_CACHE": REDIS_FULL_ADDRESS_RESPONSE_CACHE,
         "PYLAV__JAVA_EXECUTABLE": JAVA_EXECUTABLE,
         "PYLAV__LINKED_BOT_IDS": LINKED_BOT_IDS,
-        "PYLAV__USE_BUNDLED_EXTERNAL_NODES": USE_BUNDLED_EXTERNAL_NODES,
+        "PYLAV__USE_BUNDLED_EXTERNAL_LAVA_LINK_NODE": USE_BUNDLED_EXTERNAL_LAVA_LINK_NODE,
+        "PYLAV__USE_BUNDLED_EXTERNAL_PYLAV_NODE": USE_BUNDLED_EXTERNAL_PYLAV_NODE,
         "PYLAV__EXTERNAL_UNMANAGED_HOST": EXTERNAL_UNMANAGED_HOST,
         "PYLAV__EXTERNAL_UNMANAGED_PORT": EXTERNAL_UNMANAGED_PORT,
         "PYLAV__EXTERNAL_UNMANAGED_PASSWORD": EXTERNAL_UNMANAGED_PASSWORD,
@@ -96,9 +98,15 @@ else:
             LINKED_BOT_IDS = list(map(str.strip, os.getenv("PYLAV__LINKED_BOT_IDS", "").split("|")))
             data_new["PYLAV__LINKED_BOT_IDS"] = LINKED_BOT_IDS
 
-        if (USE_BUNDLED_EXTERNAL_NODES := data.get("PYLAV__USE_BUNDLED_EXTERNAL_NODES")) is None:
-            USE_BUNDLED_EXTERNAL_NODES = bool(int(os.getenv("PYLAV__USE_BUNDLED_EXTERNAL_NODES", "1")))
-            data_new["PYLAV__USE_BUNDLED_EXTERNAL_NODES"] = USE_BUNDLED_EXTERNAL_NODES
+        if (USE_BUNDLED_EXTERNAL_PYLAV_NODE := data.get("PYLAV__USE_BUNDLED_EXTERNAL_PYLAV_NODE")) is None:
+            USE_BUNDLED_EXTERNAL_PYLAV_NODE = bool(int(os.getenv("PYLAV__USE_BUNDLED_EXTERNAL_PYLAV_NODE", "1")))
+            data_new["PYLAV__USE_BUNDLED_EXTERNAL_PYLAV_NODE"] = USE_BUNDLED_EXTERNAL_PYLAV_NODE
+
+        if (USE_BUNDLED_EXTERNAL_LAVA_LINK_NODE := data.get("PYLAV__USE_BUNDLED_EXTERNAL_LAVA_LINK_NODE")) is None:
+            USE_BUNDLED_EXTERNAL_LAVA_LINK_NODE = bool(
+                int(os.getenv("PYLAV__USE_BUNDLED_EXTERNAL_LAVA_LINK_NODE", "0"))
+            )
+            data_new["PYLAV__USE_BUNDLED_EXTERNAL_LAVA_LINK_NODE"] = USE_BUNDLED_EXTERNAL_LAVA_LINK_NODE
 
         if (JAVA_EXECUTABLE := data.get("PYLAV__JAVA_EXECUTABLE")) is None:
             JAVA_EXECUTABLE = os.getenv("PYLAV__JAVA_EXECUTABLE", "java")
