@@ -266,11 +266,18 @@ class Node:
         )
 
     @property
-    def is_ready(self):
+    def is_ready(self) -> bool:
         return self._ready.is_set() and self._ws.connected
 
     @property
-    def coordinates(self):
+    def coordinates(self) -> tuple[int, int]:
+        """The coordinates of the node.
+
+        Returns
+        -------
+        :class:`tuple`
+            The coordinates of the node.
+        """
         return self._coordinates
 
     @property
@@ -370,7 +377,7 @@ class Node:
     @property
     def available(self) -> bool:
         """Returns whether the node is available for requests."""
-        return self._ws.connected
+        return self._ws.connected if self._ws else False
 
     @property
     def _original_players(self) -> list[Player]:
