@@ -9,7 +9,7 @@ import discord
 from pylav._logging import getLogger
 from pylav.events import PlayerConnectedEvent
 from pylav.player import Player
-from pylav.sql.models import PlayerModel, PlayerStateModel
+from pylav.sql.models import LibConfigModel, PlayerModel, PlayerStateModel
 
 if TYPE_CHECKING:
     from pylav.client import Client
@@ -21,18 +21,23 @@ LOGGER = getLogger("PyLav.PlayerManager")
 
 
 class PlayerManager:
-    """
-    Represents the player manager that contains all the players.
+    """Represents the player manager that contains all the players.
+
     len(x):
         Returns the total amount of cached players.
     iter(x):
         Returns an iterator of all the players cached.
+
     Attributes
     ----------
     players: :class:`dict`
         Cache of all the players that Lavalink has created.
     default_player_class: :class:`BasePlayer`
         The player that the player manager is initialized with.
+    bot: :class:`discord.Client`
+        The client that the player manager is initialized with.
+    client: :class:`Client`
+        The client that the player manager is initialized with.
     """
 
     _global_player_config: PlayerModel
@@ -42,6 +47,7 @@ class PlayerManager:
             raise ValueError("Player must implement Player.")
 
         self.client = lavalink
+        self.bot = lavalink.bot
         self.players: dict[int, Player] = {}
         self.default_player_class = player
 
@@ -83,6 +89,16 @@ class PlayerManager:
 
     async def initialize(self):
         self._global_player_config = await self.client.player_config_manager.get_global_config()
+        self.client.scheduler.add_job(
+            self.update_bot_activity,
+            trigger="interval",
+            seconds=5,
+            max_instances=1,
+            replace_existing=True,
+            name="update_bot_activity",
+            coalesce=True,
+            id=f"{self.bot.user.id}-update_bot_activity",
+        )
 
     async def destroy(self, guild_id: int, requester: discord.Member | None):
         """
@@ -120,12 +136,12 @@ class PlayerManager:
             await self._restore_player(player_state)
 
     def players(self) -> Iterator[Player]:
-        """Returns an iterator that yields only values."""
+        """Returns an iterator that yields the all :class:`Player`."""
         yield from self.players.values()
 
     def find_all(self, predicate=None):
-        """
-        Returns a list of players that match the given predicate.
+        """Returns a list of players that match the given predicate.
+
         Parameters
         ----------
         predicate: Optional[:class:`function`]
@@ -137,8 +153,8 @@ class PlayerManager:
         return [p for p in self.players.values() if bool(predicate(p))] if predicate else list(self.players.values())
 
     async def remove(self, guild_id: int) -> None:
-        """
-        Removes a player from the internal cache.
+        """Removes a player from the internal cache.
+
         Parameters
         ----------
         guild_id: :class:`int`
@@ -279,3 +295,38 @@ class PlayerManager:
             for guild_id in self.players
         ]
         await asyncio.gather(*tasks, return_exceptions=True)
+
+    async def update_bot_activity(self) -> None:
+        """
+        Updates the bot's activity.
+        """
+        if not await LibConfigModel(bot=self.bot.user.id, id=1).get_update_bot_activity():
+            return
+        playing_players = len(self.playing_players)
+        activities = self.bot.guilds[0].me.activities
+        activity = discord.utils.find(lambda a: a.type == discord.ActivityType.listening, activities)
+        if playing_players > 1:
+            if (not activity) or f"Music in {playing_players} servers" not in activity.name:
+                LOGGER.debug("Updating bot activity to %s", f"Listening to Music in {playing_players} servers")
+                await self.bot.change_presence(
+                    activity=discord.Activity(
+                        type=discord.ActivityType.listening, name=f"Music in {playing_players} servers"
+                    )
+                )
+        elif playing_players == 1:
+            current_player = self.playing_players[0]
+            if current_player.current is None:
+                return
+            track_name = await current_player.current.get_track_display_name(
+                max_length=40, author=True, unformatted=True
+            )
+            if activity and track_name in activity.name:
+                return
+            LOGGER.debug("Updating bot activity to %s", f"Listening to {track_name}")
+            await self.bot.change_presence(
+                activity=discord.Activity(type=discord.ActivityType.listening, name=track_name)
+            )
+
+        elif playing_players == 0 and activity:
+            LOGGER.debug("Removing bot activity")
+            await self.bot.change_presence(activity=None)
